aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShahbaz Youssefi <syoussefi@chromium.org>2024-04-18 10:55:34 -0400
committerAngle LUCI CQ <angle-scoped@luci-project-accounts.iam.gserviceaccount.com>2024-04-18 15:55:40 +0000
commit00fa9af9e681eb7f064a7724a9e1c8b977e25095 (patch)
tree8dd8c08a67ec9efd18fe33d857d94b7bae10af9c
parent7523c5dfd8cb44063e05adfd9eb76866c397d073 (diff)
downloadangle-00fa9af9e681eb7f064a7724a9e1c8b977e25095.tar.gz
Disable the BasicNoOpMutex test
It's flaky by nature, and the flake rate turned out to be much higher than anticipated (i.e. it cannot be ignored). Bug: b/335541479 Change-Id: Ic29c549aa761230e1d8aa8156c66e78aae939e53 Reviewed-on: https://chromium-review.googlesource.com/c/angle/angle/+/5463920 Auto-Submit: Shahbaz Youssefi <syoussefi@chromium.org> Reviewed-by: Roman Lavrov <romanl@google.com> Commit-Queue: Roman Lavrov <romanl@google.com> Commit-Queue: Shahbaz Youssefi <syoussefi@chromium.org>
-rw-r--r--src/common/SimpleMutex_unittest.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/common/SimpleMutex_unittest.cpp b/src/common/SimpleMutex_unittest.cpp
index 0b7f909e72..72db80a06b 100644
--- a/src/common/SimpleMutex_unittest.cpp
+++ b/src/common/SimpleMutex_unittest.cpp
@@ -85,8 +85,8 @@ TEST(MutexTest, BasicSimpleMutex)
EXPECT_TRUE(runBasicMutexTest<SimpleMutex>());
}
-// Tests failure with NoOpMutex.
-TEST(MutexTest, BasicNoOpMutex)
+// Tests failure with NoOpMutex. Disabled because it can and will flake.
+TEST(MutexTest, DISABLED_BasicNoOpMutex)
{
// Technically not _guaranteed_ to calculate the wrong value, but highly likely to do so.
EXPECT_FALSE(runBasicMutexTest<NoOpMutex>());